@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     jingzhou <jingzhou@uniontech.com>
-*
-* Maintainer: xiajing <xiajing@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "memorywidget.h"
 
@@ -467,6 +451,24 @@ void MemoryWidget::resetAllLabelByBase()
     }
 }
 
+
+
+/**
+ * @brief MemoryWidget::resetLabelBySeparator
+ * 按分割符位数重新设置文本
+ */
+void MemoryWidget::resetLabelBySeparator()
+{
+    if (m_memorypublic->isEmpty())
+        return;
+    QString text;
+    for (int i = 0; i < m_listwidget->count(); i++) {
+        auto wgt = static_cast<MemoryItemWidget *>(m_listwidget->itemWidget(m_listwidget->item(i)));
+        text = Utils::formatThousandsSeparators(wgt->textLabel().remove(","));
+        wgt->setTextLabel(text);
+    }
+}
+
 void MemoryWidget::initConnect()
 {
     connect(m_memorypublic, &MemoryPublic::generateDataSig, this, &MemoryWidget::generateData);
